==> activity-center-api-0.6.4.wb2-20170414.112801-1-sources.jar: cn/com/duiba/tuia/activity/center/api/common/PageDto.java <==
package cn.com.duiba.tuia.activity.center.api.common;

import java.io.Serializable;
import java.util.List;

/**
 * ClassName: PageDto <br/>
 * Function: 分页Dto. <br/>
 * date: 2017年2月23日 下午7:14:51 <br/>
 *
 * @author wubo
 * @version @param <T>
 * @since JDK 1.7
 */
public class PageDto<T extends Serializable> extends BaseDto {

    private static final long serialVersionUID = -5219671120762356693L;

    /** 总数. */
    private int               totalCount;

    /** 总页数. */
    private int               totalPage;

    /** 每页数量 */
    private int               pageSize;

    /** 当前页 */
    private int               currentPage;

    /** 偏移量 */
    private int               offset;

    /** 每页数量 */
    private int               max;

    /** The data. */
    private List<T>           list;

    /**
     * Creates a new instance of PageResultDto.
     */
    @SuppressWarnings("unused")
    private PageDto() {
        super();
    }

    /**
     * Creates a new instance of PageDto.
     *
     * @param totalAmount 总数
     * @param list 数据
     * @param offset 偏移值
     * @param max 页最大数量
     */
    public PageDto(int totalAmount, List<T> list, int offset, int max) {
        super();
        this.totalCount = totalAmount;
        this.list = list;
        this.offset = offset;
        this.max = max;
        this.pageSize = max;
        this.currentPage = offset / max + 1;
        this.totalPage = setToalPage(pageSize);
    }

    /**
     * Creates a new instance of PageDto.
     *
     * @param currentPage
     * @param pageSize
     */
    public PageDto(int currentPage, int pageSize) {
        super();
        this.max = pageSize;
        this.currentPage = currentPage;
        this.pageSize = pageSize;
        this.offset = pageSize * (currentPage - 1);
    }

    /**
     * 设置总页数.
     *
     * @param pageSize 每页记录数
     * @return the int
     */
    private int setToalPage(int pageSize) {
        if (totalCount < 0) {
            return 0;
        }
        return (totalCount + 1) / pageSize;
    }

    public int getTotalCount() {
        return totalCount;
    }

    public void setTotalCount(int totalCount) {
        this.totalCount = totalCount;
        this.totalPage = setToalPage(pageSize);
    }

    public int getCurentPage() {
        return currentPage;
    }

    public List<T> getList() {
        return list;
    }

    public void setList(List<T> list) {
        this.list = list;
    }

    public int getTotalPage() {
        return totalPage;
    }

    public int getPageSize() {
        return pageSize;
    }

    public int getOffset() {
        return offset;
    }

    public int getMax() {
        return max;
    }

}

==> activity-center-api-0.7.6.1.wb5-20170804.055924-1-sources.jar: cn/com/duiba/tuia/activity/center/api/common/PageDto.java <==
package cn.com.duiba.tuia.activity.center.api.common;

import java.io.Serializable;
import java.util.List;

/**
 * ClassName: PageDto <br/>
 * Function: 分页Dto. <br/>
 * date: 2017年2月23日 下午7:14:51 <br/>
 *
 * @author wubo
 * @version @param <T>
 * @since JDK 1.7
 * @param <T>
 */
public class PageDto<T extends Serializable> extends BaseDto {

    private static final long serialVersionUID = -5219671120762356693L;

    /** 总数. */
    private int               totalCount;

    /** 总页数. */
    private int               totalPage;

    /** 每页数量 */
    private int               pageSize;

    /** 当前页 */
    private int               currentPage;

    /** 偏移量 */
    private int               offset;

    /** 每页数量 */
    private int               max;

    /** The data. */
    private List<T>           list;

    /** 总计数据 */
    private T                 total;

    /**
     * Creates a new instance of PageResultDto.
     */
    @SuppressWarnings("unused")
    private PageDto() {
        super();
    }

    /**
     * Creates a new instance of PageDto.
     *
     * @param totalAmount 总数
     * @param list 数据
     * @param offset 偏移值
     * @param max 页最大数量
     */
    public PageDto(int totalAmount, List<T> list, int offset, int max) {
        super();
        this.totalCount = totalAmount;
        this.list = list;
        this.offset = offset;
        this.max = max;
        this.pageSize = max;
        this.currentPage = offset / max + 1;
        this.totalPage = setToalPage(pageSize);
    }

    /**
     * Creates a new instance of PageDto.
     *
     * @param currentPage
     * @param pageSize
     */
    public PageDto(int currentPage, int pageSize) {
        super();
        this.max = pageSize;
        this.currentPage = currentPage;
        this.pageSize = pageSize;
        this.offset = pageSize * (currentPage - 1);
    }

    /**
     * 设置总页数.
     *
     * @param pageSize 每页记录数
     * @return the int
     */
    private int setToalPage(int pageSize) {
        if (totalCount < 0) {
            return 0;
        }
        return (totalCount + 1) / pageSize;
    }

    public int getTotalCount() {
        return totalCount;
    }

    public void setTotalCount(int totalCount) {
        this.totalCount = totalCount;
        this.totalPage = setToalPage(pageSize);
    }

    public int getCurentPage() {
        return currentPage;
    }

    public List<T> getList() {
        return list;
    }

    public void setList(List<T> list) {
        this.list = list;
    }

    public int getTotalPage() {
        return totalPage;
    }

    public int getPageSize() {
        return pageSize;
    }

    public int getOffset() {
        return offset;
    }

    public int getMax() {
        return max;
    }

    public T getTotal() {
        return total;
    }

    public void setTotal(T total) {
        this.total = total;
    }
}
